.. Bedrock Server Manager ConnectionManager documentation file

Connection Manager
==================

.. autoclass:: bedrock_server_manager.web.websocket_manager.ConnectionManager
   :members:
   :undoc-members:
   :show-inheritance:
   :member-order: bysource

   .. automethod:: __init__
